<?php
$this->js_css->add_js('https://use.fontawesome.com/c1eaa95f2e.js');
?>
<div class="editor_switch">
    <form action="/ajax/inlineeditor/inlineeditor_admin/switch_editor" method="post">
        <input type="hidden" name="show_editor" value="<?= (int) ($show_editor === 0) ?>" />
        <button class="editor_<?= $show_editor ? 'on' : 'off' ?>" type="submit">
            <i class="fa fa-pencil"></i>
            <i class="fa fa-font"></i>
        </button>
        <label class="tooltip_editor">
            <span><?= $show_editor ? $this->lang->line('Disable inlineeditor') : $this->lang->line('Enable inlineeditor') ?></span>
        </label>     
    </form>
</div>